@@ -2,25 +2,26 @@ import React, { MouseEvent } from "react";
 import PropTypes from "prop-types";
 import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
 import { IconProp } from "@fortawesome/fontawesome-svg-core";
+import classNames from 'classnames';
 
 type WebvizToolbarButtonProps = {
     icon: IconProp;
     selected?: boolean;
     onClick?: (event: MouseEvent) => void;
+    important?: boolean;
     tooltip?: string;
 };
 
-const WebvizToolbarButton: React.FC<WebvizToolbarButtonProps> = ({ icon, selected, onClick, tooltip }) => {
+const WebvizToolbarButton: React.FC<WebvizToolbarButtonProps> = ({ icon, selected, onClick, important, tooltip }) => {
     return (
         <div className="webviz-config-tooltip-wrapper">
             <FontAwesomeIcon
                 icon={icon}
-                className={
-                    "webviz-config-plugin-button" +
-                    (selected
-                        ? " webviz-config-plugin-button-selected"
-                        : "")
-                }
+                className={classNames({
+                    "webviz-config-plugin-button": true,
+                    "webviz-config-plugin-button-selected": selected,
+                    "webviz-config-plugin-button-important": important,
+                })}
                 onClick={onClick}
             />
             <div className="webviz-config-tooltip">
@@ -43,6 +44,11 @@ WebvizToolbarButton.propTypes = {
      */
     tooltip: PropTypes.string,
 
+    /**
+     * 
+     */
+    important: PropTypes.bool,
+
     /**
      * The font awesome icon to show.
      */
